@@ -15,7 +15,7 @@ Usage::
     select_paginator: SelectPaginator = client.get_paginator("select")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Generator, TYPE_CHECKING
+from typing import Iterator, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_sdb.type_defs import (
     ListDomainsResultTypeDef,
@@ -29,20 +29,20 @@ __all__ = ("ListDomainsPaginator", "SelectPaginator")
 
 class ListDomainsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDomains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/sdb.html#SimpleDB.Paginator.ListDomains)
+    [Paginator.ListDomains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/sdb.html#SimpleDB.Paginator.ListDomains)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListDomainsResultTypeDef, None, None]:
+    ) -> Iterator[ListDomainsResultTypeDef]:
         """
-        [ListDomains.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/sdb.html#SimpleDB.Paginator.ListDomains.paginate)
+        [ListDomains.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/sdb.html#SimpleDB.Paginator.ListDomains.paginate)
         """
 
 
 class SelectPaginator(Boto3Paginator):
     """
-    [Paginator.Select documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/sdb.html#SimpleDB.Paginator.Select)
+    [Paginator.Select documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/sdb.html#SimpleDB.Paginator.Select)
     """
 
     def paginate(
@@ -50,7 +50,7 @@ class SelectPaginator(Boto3Paginator):
         SelectExpression: str,
         ConsistentRead: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[SelectResultTypeDef, None, None]:
+    ) -> Iterator[SelectResultTypeDef]:
         """
-        [Select.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/sdb.html#SimpleDB.Paginator.Select.paginate)
+        [Select.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/sdb.html#SimpleDB.Paginator.Select.paginate)
         """
